# -*- encoding: utf-8 -*-

import os
import settings
import Image, ImageDraw, ImageFont

TEXT_IMAGE_ROOT = settings.MEDIA_ROOT
TEXT_IMAGE_URL = settings.MEDIA_URL
TEXT_IMAGE_FOLDER = 'text_images'
TEXT_IMAGE_FONT = '/usr/share/fonts/truetype/freefont/FreeMono.ttf'
TEXT_IMAGE_SIZE = 16
TEXT_IMAGE_CSS_CLASS = 'text-image'
TEXT_IMAGE_COLOR = 'black'

if not hasattr(settings, 'TEXT_IMAGE_FOLDER'):
    settings.TEXT_IMAGE_FOLDER = TEXT_IMAGE_FOLDER

if not hasattr(settings, 'TEXT_IMAGE_FONT'):
    settings.TEXT_IMAGE_FONT = TEXT_IMAGE_FONT

if not hasattr(settings, 'TEXT_IMAGE_SIZE'):
    settings.TEXT_IMAGE_SIZE = TEXT_IMAGE_SIZE

if not hasattr(settings, 'TEXT_IMAGE_CSS_CLASS'):
    settings.TEXT_IMAGE_CSS_CLASS = TEXT_IMAGE_CSS_CLASS

if not hasattr(settings, 'TEXT_IMAGE_COLOR'):
    settings.TEXT_IMAGE_COLOR = TEXT_IMAGE_COLOR

text_images_folder = os.path.join(TEXT_IMAGE_ROOT, settings.TEXT_IMAGE_FOLDER)
if not os.path.exists(text_images_folder):
    os.mkdir(text_images_folder)

class Text2Image(object):
    
    text = None

    def __init__(self, text=""):
        self.text = text

    def get_path(self):
        return os.path.join(TEXT_IMAGE_ROOT, settings.TEXT_IMAGE_FOLDER, self.text)

    def generate_image(self,):
        fontPath = settings.TEXT_IMAGE_FONT
        font = ImageFont.truetype(fontPath, settings.TEXT_IMAGE_SIZE)
        size = font.getsize(self.text)
        im = Image.new('RGBA', size, (0, 0, 0, 0))
        draw = ImageDraw.Draw(im)
        draw.text((0, 0), self.text, font=font, fill=settings.TEXT_IMAGE_COLOR)
        im.save(self.get_path(), "png")

    def get_image(self,):
        path = self.get_path()
        if not os.path.exists(path):
            self.generate_image()
        return Image.open(path)

    def get_html_image(self, regenerate=False):
        if regenerate:
            self.generate_image()
        image = self.get_image()
        path = os.path.join(TEXT_IMAGE_URL, settings.TEXT_IMAGE_FOLDER, self.text)
        (width, height) = image.size
        html = "<img class='%s' src='%s'/>" % (settings.TEXT_IMAGE_CSS_CLASS, path)
        return html
    


